==> marko-4.28.6.tgz: package/src/node-require/index.js <==
"use strict";
require("../");

const path = require("path");
const resolveFrom = require("resolve-from");
const fs = require("fs");
const fsReadOptions = { encoding: "utf8" };
const MARKO_EXTENSIONS = Symbol("MARKO_EXTENSIONS");

if (process.env.MARKO_HOT_RELOAD) {
  require("../hot-reload").enable();
}

// If process was launched with browser refresh then automatically
// enable browser-refresh
require("../browser-refresh").enable();

// Adds the template.getDependencies() method needed by older versions of lasso-marko
require("../runtime/components/legacy/dependencies/html");

function normalizeExtension(extension) {
  if (extension.charAt(0) !== ".") {
    extension = "." + extension;
  }
  return extension;
}

function compile(templatePath, markoCompiler, compilerOptions) {
  if (compilerOptions) {
    compilerOptions = Object.assign(
      {},
      markoCompiler.defaultOptions,
      compilerOptions
    );
  } else {
    compilerOptions = markoCompiler.defaultOptions;
  }

  var writeToDisk = compilerOptions.writeToDisk;

  var templateSrc;
  var compiledSrc;

  if (writeToDisk === false) {
    // Don't write the compiled template to disk. Instead, load it
    // directly from the compiled source using the internals of the
    // Node.js module loading system.
    templateSrc = fs.readFileSync(templatePath, fsReadOptions);
    compiledSrc = markoCompiler.compile(templateSrc, templatePath);
  } else {
    var targetFile = templatePath + ".js";

    if (
      markoCompiler.defaultOptions.assumeUpToDate &&
      fs.existsSync(targetFile)
    ) {
      // If the target file already exists and "assumeUpToDate" then just use the previously
      // compiled template.
      return fs.readFileSync(targetFile, fsReadOptions);
    }

    var isUpToDate = markoCompiler.checkUpToDate(targetFile);

    if (isUpToDate) {
      compiledSrc = fs.readFileSync(targetFile, fsReadOptions);
    } else {
      templateSrc = fs.readFileSync(templatePath, fsReadOptions);
      compiledSrc = markoCompiler.compile(
        templateSrc,
        templatePath,
        compilerOptions
      );

      fs.writeFileSync(targetFile, compiledSrc, fsReadOptions);
    }
  }

  // We attach a path to the compiled template so that hot reloading will work.
  return compiledSrc;
}

function getLoadedTemplate(path) {
  var cached = require.cache[path];
  return cached && cached.exports.render ? cached.exports : undefined;
}

function install(options) {
  options = options || {};

  var requireExtensions = options.require // options.require introduced for testing
    ? options.require.extensions
    : require.extensions;

  var compilerOptions = Object.assign(
    { requireTemplates: true },
    options.compilerOptions
  );
  require("../compiler").configure(compilerOptions);

  var extensions = [];

  if (options.extension) {
    extensions.push(options.extension);
  }

  if (options.extensions) {
    extensions = extensions.concat(options.extensions);
  }

  if (extensions.length === 0) {
    extensions.push(".marko");
  }

  function markoRequireExtension(module, filename) {
    var targetFile = filename + ".js";
    var cachedTemplate =
      getLoadedTemplate(targetFile) || getLoadedTemplate(filename);
    if (cachedTemplate) {
      // The template has already been loaded so use the exports of the already loaded template
      module.exports = cachedTemplate;
      return;
    }

    // Resolve the appropriate compiler relative to the location of the
    // marko template file on disk using the "resolve-from" module.
    var dirname = path.dirname(filename);
    var markoCompilerModulePath = resolveFrom(dirname, "marko/compiler");
    var markoCompiler = require(markoCompilerModulePath);

    // Now use the appropriate Marko compiler to compile the Marko template
    // file to JavaScript source code:
    var compiledSrc = compile(filename, markoCompiler, compilerOptions);

    // Append ".js" to the filename since that is where we write the compiled
    // source code that is being loaded. This allows stack traces to match up.
    module._compile(compiledSrc, targetFile);
  }

  requireExtensions[MARKO_EXTENSIONS] =
    requireExtensions[MARKO_EXTENSIONS] ||
    (requireExtensions[MARKO_EXTENSIONS] = []);

  extensions.forEach((extension) => {
    extension = normalizeExtension(extension);
    requireExtensions[extension] = markoRequireExtension;
    requireExtensions[MARKO_EXTENSIONS].push(extension);
  });
}

install();

exports.install = install;

exports.getExtensions = function () {
  return require.extensions[MARKO_EXTENSIONS];
};

==> marko-5.33.17.tgz: package/src/node-require/index.js <==
"use strict";

const complain = "MARKO_DEBUG" && require("complain");
const path = require("path");
const resolveFrom = require("resolve-from");
const requiredCompilerOptions = { modules: "cjs" };
const defaultCompilerOptions = {
  // eslint-disable-next-line no-constant-condition
  sourceMaps: "MARKO_DEBUG" ? "inline" : false,
  meta: true,
};
const MARKO_EXTENSIONS = Symbol("MARKO_EXTENSIONS");

// eslint-disable-next-line no-constant-condition
if ("MARKO_DEBUG") {
  complain(
    'Using "marko/node-require" has been replaced with "@marko/compiler/register".',
  );
}

function normalizeExtension(extension) {
  if (extension.charAt(0) !== ".") {
    extension = "." + extension;
  }
  return extension;
}

function compile(templatePath, markoCompiler, userCompilerOptions) {
  return markoCompiler.compileFileSync(
    templatePath,
    Object.assign(
      {},
      defaultCompilerOptions,
      userCompilerOptions,
      requiredCompilerOptions,
    ),
  ).code;
}

function install(options) {
  options = options || {};

  var requireExtensions = options.require // options.require introduced for testing
    ? options.require.extensions
    : require.extensions;

  var compilerOptions = options.compilerOptions;

  var extensions = [];

  if (options.extension) {
    extensions.push(options.extension);
  }

  if (options.extensions) {
    extensions = extensions.concat(options.extensions);
  }

  if (extensions.length === 0) {
    extensions.push(".marko");
  }

  function markoRequireExtension(module, filename) {
    // Resolve the appropriate compiler relative to the location of the
    // marko template file on disk using the "resolve-from" module.
    var dirname = path.dirname(filename);
    var markoCompilerModulePath = resolveFrom(dirname, "@marko/compiler");
    var markoCompiler = require(markoCompilerModulePath);

    // Now use the appropriate Marko compiler to compile the Marko template
    // file to JavaScript source code:
    var compiledSrc = compile(filename, markoCompiler, compilerOptions);

    // Append ".js" to the filename since that is where we write the compiled
    // source code that is being loaded. This allows stack traces to match up.
    module._compile(compiledSrc, filename);
  }

  requireExtensions[MARKO_EXTENSIONS] =
    requireExtensions[MARKO_EXTENSIONS] ||
    (requireExtensions[MARKO_EXTENSIONS] = []);

  extensions.forEach((extension) => {
    extension = normalizeExtension(extension);
    requireExtensions[extension] = markoRequireExtension;
    requireExtensions[MARKO_EXTENSIONS].push(extension);
  });
}

install();

exports.install = install;

exports.getExtensions = function () {
  return require.extensions[MARKO_EXTENSIONS];
};

require("./browser-refresh");
